typed_descriptors
=================

.. automodule:: typed_descriptors

typed_descriptors.__all__
-------------------------

The following members were explicitly reexported using ``__all__``:

    - :py:class:`typed_descriptors.attr.Attr`
    - :py:class:`typed_descriptors.prop.Prop`
    - :py:class:`typed_descriptors.base.TypedDescriptor`
    - :py:func:`typed_descriptors.prop.cached_property`
